package org.jutils;

/*------------------------------------------------------------------------------
Name:      JUtilsException.java
Project:   jutils.org
Copyright: jutils.org, see jutils-LICENSE file
Comment:   Basic jutils exception.
Version:   $Id: JUtilsException.java,v 1.3 2000/07/13 08:43:15 winkler Exp $
------------------------------------------------------------------------------*/
/**
 * The basic exception handling class for jutils.
 * <p />
 * @author "Marcel Ruff" <ruff@swand.lake.de>
 */
public class JUtilsException extends Exception
{
   public String id;
   public String reason;

   public JUtilsException(String id, String reason) {
      this.id = id;
      this.reason = reason;
   }

   public String toString() {
      return "id=" + id + " reason=" + reason;
   }

   /**
   * Create a XML representation of the Exception.
   * <pre>
   *   &lt;exception id='" + id + "'>
   *      &lt;class>JavaClass&lt;/class>
   *      &lt;reason>&lt;![cdata[
   *        bla bla
   *      ]]>&lt;/reason>
   *   &lt;/exception>
   * </pre>
   */
   public String toXml() {
      return toXml(false);
   }

   /**
   * Create a XML representation of the Exception.
   * <pre>
   *   &lt;exception id='" + id + "'>
   *      &lt;class>JavaClass&lt;/class>
   *      &lt;reason>&lt;![cdata[
   *        bla bla
   *      ]]>&lt;/reason>
   *      &lt;stack>&lt;![CDATA[
   *       id=Property.MissingValue reason=The property '-' has no value.
   *       at org.jutils.init.Property.addArgs2Props(Property.java, Compiled Code)
   *       at org.jutils.init.Property.loadProps(Property.java, Compiled Code)
   *       at org.jutils.init.Property.&lt;init>(Property.java, Compiled Code)
   *       at org.jutils.init.Property.main(Property.java, Compiled Code)
   *     ]]>&lt;/stack>
   *   &lt;/exception>
   * </pre>
   */
   public String toXml(boolean withStackTrace) {
      StringBuffer buf = new StringBuffer(reason.length() + 256);
      buf.append("<exception id='").append(id).append("'>\n");
      buf.append("   <class>").append(getClass().getName()).append("</class>\n");
      buf.append("   <reason><![CDATA[\n      ").append(reason).append("\n   ]]></reason>\n");
      if (withStackTrace) {
         java.io.StringWriter stringWriter = new java.io.StringWriter();
         java.io.PrintWriter out = new java.io.PrintWriter(stringWriter, false);
         this.printStackTrace(out);
         out.flush();
         buf.append("   <stack><![CDATA[\n");
         buf.append("      ").append(stringWriter.getBuffer().toString());
         buf.append("   ]]></stack>\n");
      }
      buf.append("</exception>");
      return buf.toString();
   }
}
