package org.jutils.collection;

/**
 * Defines the function of a <code>Vector</code> like behavior in a more abstract way.
 * <p>------------------------------------------------------------------------------<br>
 * Name:     	DynamicList<br>
 * Project:  	jutils.org<br>
 * Copyright:	jutils, see license file<br>
 * Creation date: (05.07.2000 12:10:19)   <br>
 * Version:   <pre>$Id: DynamicList.java,v 1.2 2000/07/13 14:48:03 winkler Exp $</pre> <br>
 * ------------------------------------------------------------------------------<p>
 * @author: M.Winkler, doubleSlash GmbH
 */
public interface DynamicList {
   public static final int RETURN_NULL = 0;
   public static final int RETURN_LAST = 1;
   public static final int THROW_EXCEPTION = 2;
/**
 * The number of elements that this List can take w/o resizing.
 * <br>Creation date: (12.07.2000 14:32:24)<br>
 * @author: M.Winkler, doubleSlash GmbH
 *
 * @return int
 */
int capacity();
/**
 * Returns the number of Elements stored in this class.
 * <br>Creation date: (12.07.2000 14:31:48)<br>
 * @author: M.Winkler, doubleSlash GmbH
 *
 * @return int
 */
int count();
/**
 * Ensures that at least that much elements may be contained by this list.
 * <br>Creation date: (12.07.2000 14:48:16)<br>
 * @author: M.Winkler, doubleSlash GmbH
 *
 * @return int
 * @param newCapacity int
 */
int ensureCapacity(int newCapacity);
/**
 * Returns what happens when a false index is given to the getter and setters.
 * Is one of the following:<b>
 * <li>RETURN_NULL null is returned.</li>
 * <li>RETURN_LAST the last returned value will be returned.</li>
 * <li>THROW_EXCEPTION an exception is thrown.</li>
 * <br>Creation date: (12.07.2000 14:43:43)<br>
 * @author: M.Winkler, doubleSlash GmbH
 *
 * @return int
 */
int getIndexOutOfBoundsBehavior();
/**
 * Returns a specific element as a base object. To avoid casting, re-implement a similar method returning
 * the original type of object.
 * <br>Creation date: (12.07.2000 14:34:33)<br>
 * @author: M.Winkler, doubleSlash GmbH
 *
 * @return java.lang.Object The object at the specific position.
 * @param index int The position from which the element is taken.
 */
Object getObjectAt(int index);
/**
 * Returns true if this list automatically raises capacity when more capacity is needed.
 * <br>Creation date: (12.07.2000 14:33:31)<br>
 * @author: M.Winkler, doubleSlash GmbH
 *
 * @return boolean
 */
boolean isAutoResizing();
/**
 * Sets the default chars that will be used when making a <code>toString ()</code>.
 * @see toString(char,char,char)
 * <br>Creation date: (12.07.2000 14:38:39)<br>
 * @author: M.Winkler, doubleSlash GmbH
 *
 * @param openBracket char
 * @param separator char
 * @param closeBracket char
 */
void setListChars(char openBracket, char separator, char closeBracket);
/**
 * Returns this list inclusively all elements listed with the provided characters.
 * <br>Creation date: (12.07.2000 14:37:26)<br>
 * @author: M.Winkler, doubleSlash GmbH
 *
 * @return java.lang.String
 * @param openBracket char
 * @param separator char
 * @param closeBracket char
 */
String toString(char openBracket, char separator, char closeBracket);
}
